# Name: ?.py
#
# Authors: F. Tarissan
# Purpose: compute the fraction of new links and remove links at each time
#
# Input : line : n1 n2 t "A"/"S" sorted by t
#            "A" = add
#            "S" = remove
#
# Output : t m p d
#              m = number of links before t
#              m' = number of links at t
#              np = number of new links over all possible new links
#              nd = number of removed links over all existing links
#              fp = fraction of new links over all possible new links (-1 if division by 0)
#              fd = fraction of removed links over all existing links (-1 if division by 0)
#############################################

import sys

#####################
# GENERAL FUNCTIONS #
#####################


# read from stdin
# comute p and d for each time step
# write on standard output

def compute_pd(nb,complete):

	M=nb*(nb-1)/2

	last_m=0	

	current_t=0

	add=0
	rem=0
	

	for line in sys.stdin:
		[n1,n2,t,k]= line.strip().split()
		t=int(t)
		n1=int(n1)
		n2=int(n2)

		if t!=current_t:
			add_possible=float(M-last_m)
			rem_possible=float(last_m)

			if add_possible>0:
				p=add/add_possible
			else:
				p=-1
				
			if rem_possible>0:
				d=rem/rem_possible
			else:
				d=-1

			sys.stdout.write("%d %d %d %d %d %f %f\n"%(current_t,last_m,last_m+add-rem,add,rem,p,d))

			last_m=last_m + add - rem
			add=0
			rem=0

			if complete:
				add_possible=float(M-last_m)
				rem_possible=float(last_m)

				if add_possible>0:
					p=0
				else:
					p=-1
					
				if rem_possible>0:
					d=0
				else:
					d=-1

				for i in range(current_t+1,t):
					sys.stdout.write("%d %d %d 0 0 %f %f\n"%(i,last_m,last_m,p,d))

			current_t=t

			
		if k=="A":
			add+=1
		else:
			rem+=1


	add_possible=float(M-last_m)
	rem_possible=float(last_m)
	if add_possible>0:
		p=add/add_possible
	else:
		p=-1
				
	if rem_possible>0:
		d=rem/rem_possible
	else:
		d=-1

	sys.stdout.write("%d %d %d %d %d %f %f\n"%(current_t,last_m,last_m+add-rem,add,rem,p,d))


# Main loop
if __name__ == '__main__':
	# handling arguments
	if len(sys.argv) < 2 or len(sys.argv) > 3  :
		sys.stderr.write("Usage: %s [-c] nb_nodes\n"%sys.argv[0])
		sys.exit(1)

	# read parameters
	complete=False
	nbnodes=0

	arg1=sys.argv[1]
	if arg1=="-c" or arg1=="--complete-time":
		complete=True
		nbnodes=int(sys.argv[2])
	else:
		nbnodes=int(arg1)
	
	# compute degrees
	compute_pd(nbnodes,complete)
